==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiCGI/View/HTML/RecentLog.pm <==
#
# WiKicker
#
#  RecentLog.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RecentLog.pm,v 1.10 2004/05/30 04:10:29 naney Exp $
#
#

package WiKicker::WikiCGI::View::HTML::RecentLog;

use 5.005;
use strict;
use WiKicker::HTTP::Referer;

use WiKicker::WikiCGI::View::HTML;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::View::HTML);

sub make_html_body {
  my $self = shift;

  my $response = $self->response;

  my $db = $self->db;

  my $recent_raw_log = $self->request->attribute('recent_raw_log');
  $recent_raw_log = [] unless defined $recent_raw_log;
  my $log_size = scalar(@$recent_raw_log);
  my $time_period = $self->_time_period($recent_raw_log);

  my $time_period_string = "$time_period s";
  if ($time_period > 120) {
    $time_period_string = sprintf("%.1f m", ($time_period / 60));
  }
  my $average_string = '';
  if ($time_period != 0) {
    my $av = $log_size / ($time_period / 60);
    $average_string = sprintf(" %.1f access/m", $av);
  }

  my %count;
  my %visitor;
  my $user = 0;
  for my $item (@$recent_raw_log) {
    my $address = $item->[1];
    my $agent = $item->[7];
    my $request = $item->[4];
    $count{$request}++;
    unless (exists $visitor{"$address\n$agent"}) {
      $visitor{"$address\n$agent"}->{vid} = $user;
      $user++;
    }
    $visitor{"$address\n$agent"}->{count}++;
  }
  my $num_visitor = scalar(keys %visitor);

  $response->add_content("<p>last $log_size access ($time_period_string$average_string), $num_visitor visitors</p>");


  my $top_30 = '';
  my $top_30_js = '';
  $top_30 = qq(<ol>);
  $top_30_js = qq(<ol>);
  my $i = 0;
  for my $request (sort {$count{$b} <=> $count{$a}} keys %count) {
    $i++;
    last if $i > 30;
    my $name_link = $self->link_maker->make_page_name_link($request, '', '', 0);
    my $num = $count{$request};
    $top_30 .= qq(<li>$name_link ($num)</li>);
    $top_30_js .= qq(<li>$name_link</li>);
  }
  $top_30 .= qq(</ol>);
  $top_30_js .= qq(</ol>);
  $response->add_content($top_30);

  $response->flush;

  my $jsfile = $self->_js_file_name;
  if ($jsfile) {
    if (open(TOPJS, ">$jsfile")) {
      eval "use WiKicker::JavaScript";
      unless ($@) {
        print TOPJS WiKicker::JavaScript::to_document_write("<h2>Access Top 30</h2>\n");
        print TOPJS "\n";
        my @lines = split("\n", $top_30_js);
        for my $l (@lines) {
          print TOPJS WiKicker::JavaScript::to_document_write($l . "\n");
          print TOPJS "\n";
        }
        print TOPJS WiKicker::JavaScript::to_document_write($self->link_maker->make_page_name_link("RecentLog", '', 'more info...', 0));

      }
    }
    close(TOPJS);
  }


  $response->add_content(qq(<table>));
  $i = 0;
  for my $item (reverse @$recent_raw_log) {
    $i++;
    last if $i > 30;
    my $time = $item->[0];
    my $address = $item->[1];
    my $user_id = $item->[2] || '';
    my $user_name = $item->[3] || '';
    my $request = $item->[4];
    my $referer = $item->[6];
    my $agent   = $item->[7];
#    my $date_str = WiKicker::Time::japanese_date_html_str($time,
#                                           $self->request->user->timezone);
    my $date_str = $self->request->language_handle->date_html_str($time,
                                           $self->request->user->timezone);

    my $user_str = '';
    if ($user_id ne '' && $user_id eq $self->request->user->id) {
      $user_str = 'you';
    }
    elsif ($ENV{REMOTE_ADDR} eq $address &&
           $agent eq $ENV{HTTP_USER_AGENT}) {
      $user_str = 'you?';
    }
    else {
      $user_str = sprintf("U%03d [%03d]",
                          $visitor{"$address\n$agent"}->{vid},
                          $visitor{"$address\n$agent"}->{count}
                         );
    }

    if ($user_name ne '') {
      $user_str .= '*';
    }

    my $referer_name = $self->request->is_self_uri($referer);

    my $referer_string = '';
    if (defined $referer_name) {
      $referer_string = '[[' . WiKicker::HTML::escape($referer_name) . ']]';
    }
    else {
      $referer_string = WiKicker::HTTP::Referer->new($referer)->make_html_link;
    }

    my $name_link = '';
    if ($request =~ /(%[0-9a-fA-F][0-9a-fA-F]){3,}/) {
      $name_link = WiKicker::URI::unescape_URI($request);
      $name_link = WiKicker::HTML::escape($name_link);
    }
    else {
      $name_link = $self->link_maker->make_page_name_link($request, '', '', 0);
    }

    $response->add_content(qq(<tr><td>$date_str</td><td>$name_link</td><td>$user_str</td><td>$referer_string</td></tr>\n));
    $response->flush;
  }
  $response->add_content(qq(</table>));
}

sub _js_file_name {
  my $self = shift;

  my $flag = $self->_get_properties('RecentTop.JavaScriptInclude');
  unless (defined $flag && $flag eq 'enable') {
    return '';
  }

  my $jsfile = $self->_get_properties('RecentTop.JavaScriptInclude.file');
  if (defined $jsfile && $jsfile ne '') {
    return $jsfile;
  }

  $jsfile = $ENV{SCRIPT_FILENAME};
  if ($jsfile ne '') {
    return $jsfile . '-top.js';
  }
  return '';
}

sub _time_period {
  my ($self, $recent_raw_log) = @_;

  my $log_size = scalar(@$recent_raw_log);
  my $time_period = 0;
  if ($log_size > 1) {
    my $first_time = $recent_raw_log->[0]->[0];
    my $last_time = $recent_raw_log->[-1]->[0];
    $time_period = $last_time - $first_time;
  }
  return $time_period;
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiCGI/View/HTML/RecentLog.pm <==
#
# WiKicker
#
#  RecentLog.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: RecentLog.pm,v 1.11 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::WikiCGI::View::HTML::RecentLog;

use 5.005;
use strict;
use WiKicker::HTTP::Referer;

use WiKicker::WikiCGI::View::HTML;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::View::HTML);

sub make_html_body {
  my $self = shift;

  my $response = $self->response;

  my $db = $self->db;

  my $recent_raw_log = $self->request->attribute('recent_raw_log');
  $recent_raw_log = [] unless defined $recent_raw_log;
  my $log_size = scalar(@$recent_raw_log);
  my $time_period = $self->_time_period($recent_raw_log);

  my $time_period_string = "$time_period s";
  if ($time_period > 120) {
    $time_period_string = sprintf('%.1f m', ($time_period / 60));
  }
  my $average_string = '';
  if ($time_period != 0) {
    my $av = $log_size / ($time_period / 60);
    $average_string = sprintf(' %.1f access/m', $av);
  }

  my %count;
  my %visitor;
  my $user = 0;
  for my $item (@$recent_raw_log) {
    my $address = $item->[1];
    my $agent = $item->[7];
    my $request = $item->[4];
    $count{$request}++;
    unless (exists $visitor{"$address\n$agent"}) {
      $visitor{"$address\n$agent"}->{vid} = $user;
      $user++;
    }
    $visitor{"$address\n$agent"}->{count}++;
  }
  my $num_visitor = scalar(keys %visitor);

  $response->add_content("<p>last $log_size access ($time_period_string$average_string), $num_visitor visitors</p>");


  my $top_30 = '';
  my $top_30_js = '';
  $top_30 = qq(<ol>);
  $top_30_js = qq(<ol>);
  my $i = 0;
  for my $request (sort {$count{$b} <=> $count{$a}} keys %count) {
    $i++;
    last if $i > 30;
    my $name_link = $self->link_maker->make_page_name_link($request, '', '', 0);
    my $num = $count{$request};
    $top_30 .= qq(<li>$name_link ($num)</li>);
    $top_30_js .= qq(<li>$name_link</li>);
  }
  $top_30 .= qq(</ol>);
  $top_30_js .= qq(</ol>);
  $response->add_content($top_30);

  $response->flush;

  my $jsfile = $self->_js_file_name;
  if ($jsfile) {
    if (open(TOPJS, ">$jsfile")) {
      eval "use WiKicker::JavaScript";
      unless ($@) {
        print TOPJS WiKicker::JavaScript::to_document_write("<h2>Access Top 30</h2>\n");
        print TOPJS "\n";
        my @lines = split("\n", $top_30_js);
        for my $l (@lines) {
          print TOPJS WiKicker::JavaScript::to_document_write($l . "\n");
          print TOPJS "\n";
        }
        print TOPJS WiKicker::JavaScript::to_document_write($self->link_maker->make_page_name_link('RecentLog', '', 'more info...', 0));

      }
    }
    close(TOPJS);
  }


  $response->add_content(qq(<table>));
  $i = 0;
  for my $item (reverse @$recent_raw_log) {
    $i++;
    last if $i > 30;
    my $time = $item->[0];
    my $address = $item->[1];
    my $user_id = $item->[2] || '';
    my $user_name = $item->[3] || '';
    my $request = $item->[4];
    my $referer = $item->[6];
    my $agent   = $item->[7];
#    my $date_str = WiKicker::Time::japanese_date_html_str($time,
#                                           $self->request->user->timezone);
    my $date_str = $self->request->language_handle->date_html_str($time,
                                           $self->request->user->timezone);

    my $user_str = '';
    if ($user_id ne '' && $user_id eq $self->request->user->id) {
      $user_str = 'you';
    }
    elsif ($ENV{REMOTE_ADDR} eq $address &&
           $agent eq $ENV{HTTP_USER_AGENT}) {
      $user_str = 'you?';
    }
    else {
      $user_str = sprintf("U%03d [%03d]",
                          $visitor{"$address\n$agent"}->{vid},
                          $visitor{"$address\n$agent"}->{count}
                         );
    }

    if ($user_name ne '') {
      $user_str .= '*';
    }

    my $referer_name = $self->request->is_self_uri($referer);

    my $referer_string = '';
    if (defined $referer_name) {
      $referer_string = '[[' . WiKicker::HTML::escape($referer_name) . ']]';
    }
    else {
      $referer_string = WiKicker::HTTP::Referer->new($referer)->make_html_link;
    }

    my $name_link = '';
    if ($request =~ /(%[0-9a-fA-F][0-9a-fA-F]){3,}/) {
      $name_link = WiKicker::URI::unescape_URI($request);
      $name_link = WiKicker::HTML::escape($name_link);
    }
    else {
      $name_link = $self->link_maker->make_page_name_link($request, '', '', 0);
    }

    $response->add_content(qq(<tr><td>$date_str</td><td>$name_link</td><td>$user_str</td><td>$referer_string</td></tr>\n));
    $response->flush;
  }
  $response->add_content(qq(</table>));
}

sub _js_file_name {
  my $self = shift;

  my $flag = $self->_get_properties('RecentTop.JavaScriptInclude');
  unless (defined $flag && $flag eq 'enable') {
    return '';
  }

  my $jsfile = $self->_get_properties('RecentTop.JavaScriptInclude.file');
  if (defined $jsfile && $jsfile ne '') {
    return $jsfile;
  }

  $jsfile = $ENV{SCRIPT_FILENAME};
  if ($jsfile ne '') {
    return $jsfile . '-top.js';
  }
  return '';
}

sub _time_period {
  my ($self, $recent_raw_log) = @_;

  my $log_size = scalar(@$recent_raw_log);
  my $time_period = 0;
  if ($log_size > 1) {
    my $first_time = $recent_raw_log->[0]->[0];
    my $last_time = $recent_raw_log->[-1]->[0];
    $time_period = $last_time - $first_time;
  }
  return $time_period;
}

1;
